@@ -83,8 +83,6 @@ get_predicted_ci <- function(x, ...) {
 }
 
 
-
-
 # General method ----------------------------------------------------------
 
 #' @rdname get_predicted_ci
@@ -121,11 +119,14 @@ get_predicted_ci.default <- function(x,
     se <- .get_predicted_se_from_iter(iter = iter, dispersion_method)
     out <- .get_predicted_ci_from_iter(iter = iter, ci = ci, ci_method = ci_method)
     out <- cbind(se, out)
-    # outcome is multinomial/ordinal/cumulative
-    if (inherits(predictions, "data.frame") &&
-      "Response" %in% colnames(predictions) &&
-      "Row" %in% colnames(predictions)) {
-      out <- cbind(predictions[, c("Row", "Response")], out)
+    # outcome is multinomial/ordinal/cumulative, Component for Wiener models
+    if (inherits(predictions, "data.frame") && any(c("Component", "Response") %in% colnames(predictions)) && "Row" %in% colnames(predictions)) { # nolint
+      if ("Response" %in% colnames(predictions)) {
+        by_columns <- c("Row", "Response")
+      } else {
+        by_columns <- c("Row", "Component")
+      }
+      out <- cbind(predictions[, by_columns], out)
     }
     return(out)
   }
@@ -199,7 +200,6 @@ get_predicted_ci.mlm <- function(x, verbose = TRUE, ...) {
 }
 
 
-
 #' @export
 get_predicted_ci.polr <- function(x,
                                   predictions = NULL,
@@ -239,12 +239,6 @@ get_predicted_ci.multinom <- get_predicted_ci.mlm
 get_predicted_ci.bracl <- get_predicted_ci.mlm
 
 
-
-
-
-
-
-
 ## Convert to CI -----------
 
 .get_predicted_se_to_ci <- function(x,
@@ -380,8 +374,6 @@ get_predicted_ci.bracl <- get_predicted_ci.mlm
 }
 
 
-
-
 # Get PI ------------------------------------------------------------------
 
 .get_predicted_pi_glm <- function(x, predictions, ci = 0.95, ...) {
@@ -408,8 +400,6 @@ get_predicted_ci.bracl <- get_predicted_ci.mlm
 }
 
 
-
-
 # Interval helpers --------------------------------------------------------
 
 .get_predicted_se_from_iter <- function(iter, dispersion_method = "SD") {
@@ -432,8 +422,6 @@ get_predicted_ci.bracl <- get_predicted_ci.mlm
 }
 
 
-
-
 .get_predicted_ci_from_iter <- function(iter, ci = 0.95, ci_method = "quantile") {
   # Interval
   ci_method <- match.arg(
