@@ -11,30 +11,6 @@
 #'   where the index of the column that is being pulled is `column_index`.
 #'   Defaults to 3, which is the default statistic column for most models'
 #'   summary-output.
-#' @param component String, indicating the model component for which parameters
-#'   should be returned. The default for all models is `"all"`, which returns
-#'   the requested information for all available model components. Furthermore,
-#'   there are specific options depending on the model class. `component` then
-#'   may be one of:
-#'
-#'   - For zero-inflated models (`gmmTMB`, `hurdle`, `zeroinfl`, ...) can also
-#'     be `"conditional"` or `"zero-inflated"`. Note that the *conditional*
-#'     component is also called *count* or *mean* component, depending on the
-#'     model. `glmmTMB` also has a `"dispersion"` component.
-#'   - For models with smooth terms, `component = "smooth_terms"` returns the
-#'     test statistic for the smooth terms.
-#'   - For models of class `mhurdle`, may also be one of  `"conditional"`,
-#'     `"zero_inflated"`, `"infrequent_purchase"` or `"auxiliary"`.
-#'   - For models of class `clm2` or `clmm2`, may also be `"scale"`.
-#'   - For models of class `betareg`, `betaor` or `betamfx`, may also be
-#'     `"precision"`. For other `*mfx` models (`logitmfx`, `betamfx`, ...),
-#'     may also be `"marginal"`.
-#'   - For models of class `mvord`, may also be `"thresholds"` or
-#'     `"correlation"`.
-#'   - For models of class `selection`, may also be `"selection"`, `"outcome"`
-#'     or `"auxiliary"`.
-#'   - For models of class `glmx`, may also be `"extra"`.
-#'   - For models of class `averaging`, may also be `"full"`.
 #' @param robust Logical, if `TRUE`, test statistic based on robust
 #'   standard errors is returned.
 #' @param adjust Character value naming the method used to adjust p-values or
@@ -42,9 +18,12 @@
 #' @param ci Confidence Interval (CI) level. Default to `0.95` (`95%`).
 #'   Currently only applies to objects of class `emmGrid`.
 #' @param ... Currently not used.
+#' @inheritParams find_predictors
 #' @inheritParams get_parameters
 #' @inheritParams get_parameters.emmGrid
 #'
+#' @inheritSection find_predictors Model components
+#'
 #' @return A data frame with the model's parameter names and the related test
 #'   statistic.
 #'
@@ -876,7 +855,7 @@ get_statistic.mvord <- function(x, component = "all", ...) {
 
   params <- rbind(params, params_error)
 
-  if (n_unique(params$Response) == 1) {
+  if (has_single_value(params$Response, remove_na = TRUE)) {
     params$Response <- NULL
   }
 
@@ -1687,14 +1666,14 @@ get_statistic.emm_list <- function(x, ci = 0.95, adjust = "none", ...) {
 
 #' @export
 get_statistic.ggcomparisons <- function(x, merge_parameters = FALSE, ...) {
-  estimate_pos <- which(colnames(x) == attr(x, "estimate_name"))
   if (isTRUE(merge_parameters)) {
     params <- get_parameters(x, merge_parameters = TRUE)["Parameter"]
   } else {
-    params <- x[, seq_len(estimate_pos - 1), drop = FALSE]
+    params <- get_parameters(x, merge_parameters = FALSE)[c("Level1", "Level2")]
   }
 
-  stat <- .safe(x[[estimate_pos]] / attributes(x)$standard_error)
+  stat_column <- intersect(colnames(x), c("t", "z", "Statistic"))[1]
+  stat <- x[[stat_column]]
   if (is.null(stat)) {
     return(NULL)
   }
@@ -2079,10 +2058,8 @@ get_statistic.nlrq <- get_statistic.rq
 
 
 #' @export
-get_statistic.rqss <- function(x,
-                               component = c("all", "conditional", "smooth_terms"),
-                               ...) {
-  component <- match.arg(component)
+get_statistic.rqss <- function(x, component = "all", ...) {
+  component <- validate_argument(component, c("all", "conditional", "smooth_terms"))
 
   cs <- summary(x)
   stat <- c(as.vector(cs$coef[, "t value"]), as.vector(cs$qsstab[, "F value"]))
