@@ -384,10 +384,6 @@
 }
 
 
-
-
-
-
 # add remainng variables with special pattern -------------------------------
 
 .add_remaining_missing_variables <- function(model,
@@ -496,10 +492,6 @@
 }
 
 
-
-
-
-
 # combine data from different model components -------------------------------
 
 # This helper functions ensures that data from different model components
@@ -516,22 +508,30 @@
       all = c(
         sapply(model.terms[-1], function(i) i$conditional),
         sapply(model.terms[-1], function(i) i$zero_inflated),
+        sapply(model.terms[-1], function(i) i$zi),
         sapply(model.terms[-1], function(i) i$dispersion)
       ),
       conditional = sapply(model.terms[-1], function(i) i$conditional),
       zi = ,
-      zero_inflated = sapply(model.terms[-1], function(i) i$zero_inflated),
+      zero_inflated = c(
+        sapply(model.terms[-1], function(i) i$zero_inflated),
+        sapply(model.terms[-1], function(i) i$zi)
+      ),
       dispersion = sapply(model.terms[-1], function(i) i$dispersion)
     )
 
     random.component.data <- switch(component,
       all = c(
         sapply(model.terms[-1], function(i) i$random),
-        sapply(model.terms[-1], function(i) i$zero_inflated_random)
+        sapply(model.terms[-1], function(i) i$zero_inflated_random),
+        sapply(model.terms[-1], function(i) i$zi_random)
       ),
       conditional = sapply(model.terms[-1], function(i) i$random),
       zi = ,
-      zero_inflated = sapply(model.terms[-1], function(i) i$zero_inflated_random)
+      zero_inflated = c(
+        sapply(model.terms[-1], function(i) i$zero_inflated_random),
+        sapply(model.terms[-1], function(i) i$zi_random)
+      )
     )
 
     fixed.component.data <- unlist(fixed.component.data, use.names = FALSE)
@@ -542,15 +542,15 @@
       all = unlist(model.terms[all_elements], use.names = FALSE),
       conditional = model.terms$conditional,
       zi = ,
-      zero_inflated = model.terms$zero_inflated,
+      zero_inflated = c(model.terms$zero_inflated, model.terms$zi),
       dispersion = model.terms$dispersion
     )
 
     random.component.data <- switch(component,
-      all = c(model.terms$random, model.terms$zero_inflated_random),
+      all = c(model.terms$random, model.terms$zero_inflated_random, model.terms$zi_random),
       conditional = model.terms$random,
       zi = ,
-      zero_inflated = model.terms$zero_inflated_random
+      zero_inflated = c(model.terms$zero_inflated_random, model.terms$zi_random)
     )
   }
 
@@ -608,9 +608,6 @@
 }
 
 
-
-
-
 # find zi-data -----------------------------------
 
 # this function tries to get the data from variables from the zero-inflated
@@ -618,6 +615,9 @@
 # has other variables than the count component.
 #
 .add_zeroinf_data <- function(x, mf, tn) {
+  if (is.null(tn)) {
+    return(mf)
+  }
   tryCatch(
     {
       env_data <- .recover_data_from_environment(x)[, tn, drop = FALSE]
@@ -630,8 +630,6 @@
 }
 
 
-
-
 # special model handling -----------------------------------
 
 .get_zelig_relogit_frame <- function(x) {
@@ -640,8 +638,6 @@
 }
 
 
-
-
 # combine data from count and zi-component -----------------------------------
 
 .return_zeroinf_data <- function(x, component, verbose = TRUE) {
@@ -652,20 +648,24 @@
   mf <- .prepare_get_data(x, mf, verbose = verbose)
   # add variables from other model components
   mf <- .add_zeroinf_data(x, mf, model.terms$zero_inflated)
+  mf <- .add_zeroinf_data(x, mf, model.terms$zi)
 
   fixed.data <- switch(component,
-    all = c(model.terms$conditional, model.terms$zero_inflated, model.terms$offset),
+    all = c(
+      model.terms$conditional,
+      model.terms$zero_inflated,
+      model.terms$zi,
+      model.terms$offset
+    ),
     conditional = c(model.terms$conditional, model.terms$offset),
     zi = ,
-    zero_inflated = model.terms$zero_inflated
+    zero_inflated = c(model.terms$zero_inflated, model.terms$zi)
   )
 
   mf[, unique(c(model.terms$response, fixed.data, find_weights(x))), drop = FALSE]
 }
 
 
-
-
 # "clean" model frame and get data -----------------------------------
 
 # here we have a model frame with many variables, so just extract the important ones...
@@ -689,8 +689,6 @@
 }
 
 
-
-
 # find start vector of nlmer-models from the environment -----------------------------------
 
 # return data from a data frame that is in the environment,
@@ -704,9 +702,6 @@
 }
 
 
-
-
-
 # backtransform variables -------------------------------
 
 .backtransform <- function(mf, x) {
@@ -788,7 +783,6 @@
 }
 
 
-
 .unscale <- function(x) {
   m <- attr(x, "scaled:center")
   s <- attr(x, "scaled:scale")
@@ -800,7 +794,6 @@
 }
 
 
-
 # find transformed terms, to convert back as raw data --------------------------------
 
 # Find transformed terms inside model formula, and return "clean" term names
