@@ -1,6 +1,3 @@
-data(iris)
-data(mtcars)
-
 m1 <- lm(Sepal.Length ~ Petal.Width + Species, data = iris)
 m2 <- lm(log(mpg) ~ log(hp) + cyl + I(cyl^2) + poly(wt, degree = 2, raw = TRUE),
   data = mtcars
@@ -78,13 +75,10 @@ test_that("get_df", {
 })
 
 test_that("get_data", {
-  expect_equal(nrow(get_data(m1)), 150)
-  expect_equal(
-    colnames(get_data(m1)),
-    c("Sepal.Length", "Petal.Width", "Species")
-  )
-  expect_equal(nrow(get_data(m2)), 32)
-  expect_equal(colnames(get_data(m2)), c("mpg", "hp", "cyl", "wt"))
+  expect_identical(nrow(get_data(m1)), 150L)
+  expect_named(get_data(m1), c("Sepal.Length", "Petal.Width", "Species"))
+  expect_identical(nrow(get_data(m2)), 32L)
+  expect_named(get_data(m2), c("mpg", "hp", "cyl", "wt"))
 })
 
 test_that("get_intercept", {
@@ -113,14 +107,14 @@ test_that("find_formula", {
 })
 
 test_that("find_terms", {
-  expect_equal(
+  expect_identical(
     find_terms(m1),
     list(
       response = "Sepal.Length",
       conditional = c("Petal.Width", "Species")
     )
   )
-  expect_equal(
+  expect_identical(
     find_terms(m2),
     list(
       response = "log(mpg)",
@@ -132,11 +126,11 @@ test_that("find_terms", {
       )
     )
   )
-  expect_equal(
+  expect_identical(
     find_terms(m1, flatten = TRUE),
     c("Sepal.Length", "Petal.Width", "Species")
   )
-  expect_equal(
+  expect_identical(
     find_terms(m2, flatten = TRUE),
     c(
       "log(mpg)",
@@ -149,29 +143,29 @@ test_that("find_terms", {
 })
 
 test_that("find_variables", {
-  expect_equal(
+  expect_identical(
     find_variables(m1),
     list(
       response = "Sepal.Length",
       conditional = c("Petal.Width", "Species")
     )
   )
-  expect_equal(find_variables(m2), list(
+  expect_identical(find_variables(m2), list(
     response = "mpg",
     conditional = c("hp", "cyl", "wt")
   ))
-  expect_equal(
+  expect_identical(
     find_variables(m1, flatten = TRUE),
     c("Sepal.Length", "Petal.Width", "Species")
   )
-  expect_equal(
+  expect_identical(
     find_variables(m2, flatten = TRUE),
     c("mpg", "hp", "cyl", "wt")
   )
 })
 
 test_that("find_parameters", {
-  expect_equal(
+  expect_identical(
     find_parameters(m1),
     list(
       conditional = c(
@@ -182,8 +176,8 @@ test_that("find_parameters", {
       )
     )
   )
-  expect_equal(nrow(get_parameters(m1)), 4)
-  expect_equal(
+  expect_identical(nrow(get_parameters(m1)), 4L)
+  expect_identical(
     get_parameters(m1)$Parameter,
     c(
       "(Intercept)",
@@ -197,7 +191,7 @@ test_that("find_parameters", {
 
 test_that("find_parameters summary.lm", {
   s <- summary(m1)
-  expect_equal(
+  expect_identical(
     find_parameters(s),
     list(
       conditional = c(
@@ -216,7 +210,7 @@ test_that("linkfun", {
 })
 
 test_that("find_algorithm", {
-  expect_equal(find_algorithm(m1), list(algorithm = "OLS"))
+  expect_identical(find_algorithm(m1), list(algorithm = "OLS"))
 })
 
 test_that("get_variance", {
@@ -238,7 +232,7 @@ test_that("all_models_equal", {
 })
 
 test_that("get_varcov", {
-  expect_equal(diag(get_varcov(m1)), diag(vcov(m1)))
+  expect_equal(diag(get_varcov(m1)), diag(vcov(m1)), tolerance = 1e-5)
 })
 
 test_that("get_statistic", {
@@ -246,7 +240,7 @@ test_that("get_statistic", {
 })
 
 test_that("find_statistic", {
-  expect_equal(find_statistic(m1), "t-statistic")
+  expect_identical(find_statistic(m1), "t-statistic")
 })
 
 
@@ -290,7 +284,6 @@ test_that("find_statistic", {
 })
 
 test_that("find_statistic", {
-  data("mtcars")
   m <- lm(cbind(mpg, hp) ~ cyl + drat, data = mtcars)
   expect_message(
     get_predicted(m),
